Cloud class

Constructors

Cloud(String owner, String distribution)

Properties

hashCode int
The hash code for this object.
no setterinherited
readyCallbacks List<Function>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleReadyCallbacks() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic message) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited