Context class

Constructors

Context(String owner, String distribution)

Properties

cloud Cloud
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recipes → dynamic
no setter
recipesBind Listenable
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

increment() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recipeBind(Data<String> id) Listenable
recipeData(Data<String> id) Data<Map<String, Data>>
toString() String
A string representation of this object.
inherited
update(String kind, String id, dynamic data) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited