DataSearch class

Constructors

DataSearch({required String needle, required String haystack})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasMatch bool
latefinal
positions List<int>
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited