value property
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
Implementation
@override
get value {
return _value;
}
The current value of the object.
When the value changes, the callbacks registered with addListener will be invoked.
@override
get value {
return _value;
}