drop'in Recipes Flutter package
Features
This package provides Flutter components and utilities for building applications that interact with the drop'in ecosystem.
Getting started
At this time, this package is under active development. You can browse the source code if you are curious, but there are no stable APIs yet. Please check back later for updates.
Usage
To use this package, add it as a dependency in your Flutter project's
pubspec.yaml file:
dependencies:
dropin_recipes: any
Then run flutter pub get to install the package.
Additional information
If you have any questions or need further assistance, please visit the project's GitHub Discussions: https://github.com/blue-forest/dropin/discussions