Data<T> class
- Inheritance
-
- Object
- ChangeNotifier
- Data
- Implemented types
Properties
- exists → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
parents
↔ List<
Data> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
The current value of the object.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addParent(
Data parent) → void -
clear(
{bool notify = true}) → void -
copy(
) → Data -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
get(
List< String> ? keys) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
putIfAbsent(
dynamic key, Data ifAbsent, {bool notify = true}) → dynamic -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
round(
double? decimals, String? type) → double -
set(
dynamic newValue, {bool notify = true}) → void -
toColor(
) → Color -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
insert(
Data list, Data value, {bool notify = true, int? index}) → void -
map(
dynamic mapOrList, dynamic callback(Data, dynamic)) → List -
max(
dynamic value) → dynamic -
min(
dynamic value) → dynamic -
parseDouble(
dynamic value) → double -
parseString(
dynamic value) → String -
reduce(
dynamic value, dynamic callback(dynamic, dynamic)) → dynamic -
remove(
Data mapOrList, dynamic value, {bool notify = true, bool findValue = false}) → dynamic -
removeAllRecipeValue(
dynamic value) → dynamic -
sameToOne(
Data mapOrList, dynamic value) → bool -
search(
dynamic mapOrList, String query) → dynamic -
toGradient(
{Data? colors, Data? linear, Data? radial, Data? sweep}) → Gradient?